+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0105      ; [.1210.0020.0002.0105] # LATIN SMALL LETTER A WITH OGONEK
0061 0328 ; [.1210.0020.0002.0105] # LATIN SMALL LETTER A WITH OGONEK
0104      ; [.1210.0020.0008.0104] # LATIN CAPITAL LETTER A WITH OGONEK
0041 0328 ; [.1210.0020.0008.0104] # LATIN CAPITAL LETTER A WITH OGONEK
0107      ; [.123E.0020.0002.0107] # LATIN SMALL LETTER C WITH ACUTE
0063 0301 ; [.123E.0020.0002.0107] # LATIN SMALL LETTER C WITH ACUTE
0106      ; [.123E.0020.0008.0106] # LATIN CAPITAL LETTER C WITH ACUTE
0043 0301 ; [.123E.0020.0008.0106] # LATIN CAPITAL LETTER C WITH ACUTE
0119      ; [.126C.0020.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0065 0328 ; [.126C.0020.0002.0119] # LATIN SMALL LETTER E WITH OGONEK
0118      ; [.126C.0020.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
0045 0328 ; [.126C.0020.0008.0118] # LATIN CAPITAL LETTER E WITH OGONEK
0142      ; [.1331.0020.0002.0142] # LATIN SMALL LETTER L WITH STROKE
006C 0335 ; [.1331.0020.0002.0142] # LATIN SMALL LETTER L WITH STROKE
0141      ; [.1331.0020.0008.0141] # LATIN CAPITAL LETTER L WITH STROKE
004C 0335 ; [.1331.0020.0008.0141] # LATIN CAPITAL LETTER L WITH STROKE
0144      ; [.136E.0020.0002.0144] # LATIN SMALL LETTER N WITH ACUTE
006E 0301 ; [.136E.0020.0002.0144] # LATIN SMALL LETTER N WITH ACUTE
0143      ; [.136E.0020.0008.0143] # LATIN CAPITAL LETTER N WITH ACUTE
004E 0301 ; [.136E.0020.0008.0143] # LATIN CAPITAL LETTER N WITH ACUTE
00F3      ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0301 ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
00D3      ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0301 ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
015B      ; [.1411.0020.0002.015B] # LATIN SMALL LETTER S WITH ACUTE
0073 0301 ; [.1411.0020.0002.015B] # LATIN SMALL LETTER S WITH ACUTE
015A      ; [.1411.0020.0008.015A] # LATIN CAPITAL LETTER S WITH ACUTE
0053 0301 ; [.1411.0020.0008.015A] # LATIN CAPITAL LETTER S WITH ACUTE
017A      ; [.14AE.0020.0002.017A] # LATIN SMALL LETTER Z WITH ACUTE
007A 0301 ; [.14AE.0020.0002.017A] # LATIN SMALL LETTER Z WITH ACUTE
0179      ; [.14AE.0020.0008.0179] # LATIN CAPITAL LETTER Z WITH ACUTE
005A 0301 ; [.14AE.0020.0008.0179] # LATIN CAPITAL LETTER Z WITH ACUTE
017C      ; [.14AF.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
007A 0307 ; [.14AF.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
017B      ; [.14AF.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
005A 0307 ; [.14AF.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
ENTRY
};
