+{
   entry => <<'ENTRY', # for DUCET v5.2.0
010D      ; [.123E.0020.0002.010D] # LATIN SMALL LETTER C WITH CARON
0063 030C ; [.123E.0020.0002.010D] # LATIN SMALL LETTER C WITH CARON
010C      ; [.123E.0020.0008.010C] # LATIN CAPITAL LETTER C WITH CARON
0043 030C ; [.123E.0020.0008.010C] # LATIN CAPITAL LETTER C WITH CARON
0063 0068 ; [.12D4.0020.0002.0063] # <LATIN SMALL LETTER C, LATIN SMALL LETTER H>
0063 0048 ; [.12D4.0020.0007.0063][.0000.0000.0002.0000] # <LATIN SMALL LETTER C, LATIN CAPITAL LETTER H>
0043 0068 ; [.12D4.0020.0007.0043][.0000.0000.0008.0000] # <LATIN CAPITAL LETTER C, LATIN SMALL LETTER H>
0043 0048 ; [.12D4.0020.0008.0043] # <LATIN CAPITAL LETTER C, LATIN CAPITAL LETTER H>
0159      ; [.13DB.0020.0002.0159] # LATIN SMALL LETTER R WITH CARON
0072 030C ; [.13DB.0020.0002.0159] # LATIN SMALL LETTER R WITH CARON
0158      ; [.13DB.0020.0008.0158] # LATIN CAPITAL LETTER R WITH CARON
0052 030C ; [.13DB.0020.0008.0158] # LATIN CAPITAL LETTER R WITH CARON
0161      ; [.1411.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.1411.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.1411.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.1411.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
017E      ; [.14AE.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.14AE.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.14AE.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.14AE.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
ENTRY
};
